@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -65,7 +68,7 @@ OSDefineMetaClassAndStructors( BMacEnet, IOEthernetController )
  *
  *-------------------------------------------------------------------------*/
 
-bool BMacEnet::init(OSDictionary * properties = 0)
+bool BMacEnet::init( OSDictionary* properties )
 {
     if ( super::init(properties) == false )
         return false;
@@ -209,58 +212,67 @@ bool BMacEnet::start(IOService * provider)
 	IOWorkLoop * myWorkLoop = getWorkLoop();
 	assert(myWorkLoop);
 
-	//
-	// Allocate three IOInterruptEventSources.
-	//
-	rxIntSrc = IOInterruptEventSource::interruptEventSource
-            (this,
-             (IOInterruptEventAction) &BMacEnet::interruptOccurredForSource,
-             provider, PROVIDER_DMA_RX);
-        if (!rxIntSrc
-        || (myWorkLoop->addEventSource(rxIntSrc) != kIOReturnSuccess)) {
-		IOLog("Ethernet(BMac): rxIntSrc init failure\n");
+		// Allocate three IOInterruptEventSources:
+
+	rxIntSrc = IOInterruptEventSource::interruptEventSource(
+					this,
+					(IOInterruptEventAction)&BMacEnet::interruptOccurred,
+					provider,
+					PROVIDER_DMA_RX );
+	if ( !rxIntSrc || (myWorkLoop->addEventSource( rxIntSrc ) != kIOReturnSuccess) )
+	{
+		IOLog( "BMacEnet::start - rxIntSrc init failure\n" );
 		return false;
 	}
 
-	intES = IOInterruptEventSource::interruptEventSource
-            (this,
-             (IOInterruptEventAction) &BMacEnet::interruptOccurredForSource,
-             provider, PROVIDER_DMA_TX);
-        if (intES) {
-            bool res = (myWorkLoop->addEventSource(intES) != kIOReturnSuccess);
-            intES->release();
-            if (res) {
-		IOLog("Ethernet(BMac): PROVIDER_DMA_TX add failure\n");
-                return false;
-            }
-        }
-        else {
-		IOLog("Mace: PROVIDER_DMA_TX init failure\n");
+	intES = IOInterruptEventSource::interruptEventSource(
+					this,
+					(IOInterruptEventAction)&BMacEnet::interruptOccurred,
+					provider,
+					PROVIDER_DMA_TX );
+	if ( intES )
+	{
+		bool res = (myWorkLoop->addEventSource( intES ) != kIOReturnSuccess );
+		intES->release();
+		if ( res )
+		{
+			IOLog( "BMacEnet::start -  PROVIDER_DMA_TX add failure\n" );
+			return false;
+		}
+	}
+	else
+	{
+		IOLog( "BMacEnet::start - PROVIDER_DMA_TX init failure\n" );
 		return false;
 	}
-	
-	intES = IOInterruptEventSource::interruptEventSource
-            (this,
-             (IOInterruptEventAction) &BMacEnet::interruptOccurredForSource,	
-	     provider, PROVIDER_DEV);	
-	if (intES) {	
-	    bool res = (myWorkLoop->addEventSource(intES) != kIOReturnSuccess);	
-	    intES->release();	
-	    if (res) {
-		IOLog("Ethernet(BMac): PROVIDER_DEV add failure\n");	
-	        return false;	
-	    }	
-	}	
-	else {
-		IOLog("Ethernet(BMac): PROVIDER_DEV init failure\n");
+
+	intES = IOInterruptEventSource::interruptEventSource(
+					this,
+					(IOInterruptEventAction)&BMacEnet::interruptOccurred,
+					provider,
+					PROVIDER_DEV );
+	if ( intES )
+	{
+	    bool res = (myWorkLoop->addEventSource( intES ) != kIOReturnSuccess);
+	    intES->release();
+	    if ( res )
+		{
+			IOLog( "BMacEnet::start - PROVIDER_DEV add failure\n" );
+			return false;
+	    }
+	}
+	else
+	{
+		IOLog( "BMacEnet::start - PROVIDER_DEV init failure\n" );
 		return false;
 	}
-	
-	timerSrc = IOTimerEventSource::timerEventSource
-            (this, (IOTimerEventSource::Action) &BMacEnet::timeoutOccurred);
-	if (!timerSrc
-	|| (myWorkLoop->addEventSource(timerSrc) != kIOReturnSuccess)) {
-		IOLog("Ethernet(BMac): timerSrc init failure\n");
+
+	timerSrc = IOTimerEventSource::timerEventSource(
+					this,
+					(IOTimerEventSource::Action)&BMacEnet::timerPopped );
+	if ( !timerSrc || (myWorkLoop->addEventSource( timerSrc ) != kIOReturnSuccess) )
+	{
+		IOLog( "BMacEnet::start - timerSrc init failure\n" );
 		return false;
 	}
 
@@ -372,10 +384,16 @@ void BMacEnet::free()
 	for (i = 0; i < MEMORY_MAP_COUNT; i++)
 		if (maps[i]) maps[i]->release();
 
-	if (dmaMemory.ptr)
+	if ( dmaCommandsDesc )
+	{	dmaCommandsDesc->complete(  kIODirectionOutIn );
+		dmaCommandsDesc->release();
+		dmaCommandsDesc = 0;
+	}
+
+	if ( dmaCommands )
 	{
-		IOFree(dmaMemory.ptrReal, dmaMemory.sizeReal);
-		dmaMemory.ptr = 0;
+		IOFreeContiguous( dmaCommands, dmaCommandsSize );
+		dmaCommands = 0;
 	}
 
     if ( workLoop )
@@ -385,7 +403,9 @@ void BMacEnet::free()
     }
 
 	super::free();
-}
+	return;
+}/* end free */
+
 
 /*-------------------------------------------------------------------------
  * Override IONetworkController::createWorkLoop() method and create
@@ -417,8 +437,14 @@ IOWorkLoop * BMacEnet::getWorkLoop() const
  *
  *-------------------------------------------------------------------------*/
 
-void BMacEnet::interruptOccurredForSource(IOInterruptEventSource *src,
-		 int /*count*/)
+void BMacEnet::interruptOccurred( OSObject *me, IOInterruptEventSource *src, int /*count*/ )
+{
+	((BMacEnet*)me)->handleInterrupt( src );
+	return;
+}/* end interruptOccurred */
+
+
+void BMacEnet::handleInterrupt( IOInterruptEventSource *src )
 {
 	bool doFlushQueue = false;
 	bool doService    = false;
@@ -463,7 +489,9 @@ void BMacEnet::interruptOccurredForSource(IOInterruptEventSource *src,
 	 */
 	if ( doService && netifEnabled )
 		transmitQueue->service();
-}
+	return;
+}/* end handleInterrupt */
+
 
 /*-------------------------------------------------------------------------
  *
@@ -759,7 +787,14 @@ IOReturn BMacEnet::disable(IOKernelDebugger * /*debugger*/)
  *
  *-------------------------------------------------------------------------*/
 
-void BMacEnet::timeoutOccurred(IOTimerEventSource * /*timer*/)
+void BMacEnet::timerPopped( OSObject *me, IOTimerEventSource* /*timer*/ )
+{
+	((BMacEnet*)me)->handleTimerPop();
+	return;
+}/* end timerPopped */
+
+
+void BMacEnet::handleTimerPop()
 {
     u_int32_t       dmaStatus;
 	bool            doFlushQueue = false;
@@ -860,11 +895,10 @@ void BMacEnet::timeoutOccurred(IOTimerEventSource * /*timer*/)
 		transmitQueue->service();
 	}
 
-    /*
-     * Restart the watchdog timer
-     */
-	timerSrc->setTimeoutMS(WATCHDOG_TIMER_MS);
-}
+	timerSrc->setTimeoutMS( WATCHDOG_TIMER_MS );	/* Restart the watchdog timer	*/
+	return;
+}/* end handleTimerPop */
+
 
 /*-------------------------------------------------------------------------
  *
